============
Installation
============


Packages requirements
---------------------

 * numpy
 * matplotlib
 * pylab
 * pandas
 * fortranformat

pymad8 is developed for Python 3 but should be Python 2 compatible.

Installation
------------


To install pymad8, simply run ``make install`` from the root pymad8
directory.::

  cd /my/path/to/repositories/
  git clone http://bitbucket.org/jairhul/pymad8
  cd pymad8
  make install

Alternatively, run ``make develop`` from the same directory to ensure
that any local changes are picked up.
